@@ -1,5 +1,5 @@
 package App::Tangerine;
-$App::Tangerine::VERSION = '0.19';
+$App::Tangerine::VERSION = '0.20';
 # ABSTRACT: Perl dependency metadata tool
 use 5.010;
 use strict;
@@ -311,6 +311,10 @@ A perl dependency metadata reporting tool built on top of Tangerine.
 
 L<tangerine>, L<Tangerine>
 
+=head1 REPOSITORY
+
+L<https://github.com/contyk/tangerine>
+
 =head1 AUTHOR
 
 Petr Šabata <contyk@redhat.com>
